prompt --application/set_environment
set define off verify off feedback off
whenever sqlerror exit sql.sqlcode rollback
--------------------------------------------------------------------------------
--
-- ORACLE Application Express (APEX) export file
--
-- You should run the script connected to SQL*Plus as the Oracle user
-- APEX_180200 or as the owner (parsing schema) of the application.
--
-- NOTE: Calls to apex_application_install override the defaults below.
--
--------------------------------------------------------------------------------
begin
wwv_flow_api.import_begin (
 p_version_yyyy_mm_dd=>'2016.08.24'
,p_release=>'5.1.3.00.05'
,p_default_workspace_id=>21717127411908241868
,p_default_application_id=>103428
,p_default_owner=>'RD_DEV'
);
end;
/
prompt --application/shared_components/plugins/dynamic_action/apex_notification
begin
wwv_flow_api.create_plugin(
 p_id=>wwv_flow_api.id(138285470529447569213)
,p_plugin_type=>'DYNAMIC ACTION'
,p_name=>'APEX.NOTIFICATION'
,p_display_name=>'APEX Notification Menu'
,p_category=>'NOTIFICATION'
,p_supported_ui_types=>'DESKTOP:JQM_SMARTPHONE'
,p_plsql_code=>wwv_flow_string.join(wwv_flow_t_varchar2(
'FUNCTION F_AJAX (',
'    P_DYNAMIC_ACTION   IN APEX_PLUGIN.T_DYNAMIC_ACTION,',
'    P_PLUGIN           IN APEX_PLUGIN.T_PLUGIN',
') RETURN APEX_PLUGIN.T_DYNAMIC_ACTION_AJAX_RESULT IS',
'    VR_RESULT         APEX_PLUGIN.T_DYNAMIC_ACTION_AJAX_RESULT;',
'BEGIN',
'    APEX_UTIL.JSON_FROM_SQL( SQLQ   => P_DYNAMIC_ACTION.ATTRIBUTE_04 );',
'    RETURN VR_RESULT;',
'END;',
'',
'FUNCTION F_RENDER (',
'    P_DYNAMIC_ACTION   IN APEX_PLUGIN.T_DYNAMIC_ACTION,',
'    P_PLUGIN           IN APEX_PLUGIN.T_PLUGIN',
') RETURN APEX_PLUGIN.T_DYNAMIC_ACTION_RENDER_RESULT AS',
'    VR_RESULT         APEX_PLUGIN.T_DYNAMIC_ACTION_RENDER_RESULT;',
'    VR_REQUIRE_ESCAPE BOOLEAN := TRUE;',
'BEGIN',
'    APEX_CSS.ADD_FILE(',
'        P_NAME        => ''style.min'',',
'        P_DIRECTORY   => P_PLUGIN.FILE_PREFIX,',
'        P_VERSION     => NULL,',
'        P_KEY         => ''noteMenuStyle''',
'    );',
'',
'    APEX_JAVASCRIPT.ADD_LIBRARY(',
'        P_NAME        => ''script.min'',',
'        P_DIRECTORY   => P_PLUGIN.FILE_PREFIX,',
'        P_VERSION     => NULL,',
'        P_KEY         => ''noteMenuSource''',
'    );',
'',
'    IF',
'        P_DYNAMIC_ACTION.ATTRIBUTE_05 = ''N''',
'    THEN',
'        VR_REQUIRE_ESCAPE   := FALSE;',
'    ELSE',
'        VR_REQUIRE_ESCAPE   := TRUE;',
'    END IF;',
'',
'    VR_RESULT.JAVASCRIPT_FUNCTION   := ''function () {',
'  notificationMenu.initialize('' ||',
'    APEX_JAVASCRIPT.ADD_VALUE( P_DYNAMIC_ACTION.ATTRIBUTE_02, TRUE ) ||',
'    APEX_JAVASCRIPT.ADD_VALUE( APEX_PLUGIN.GET_AJAX_IDENTIFIER, TRUE ) ||',
'    APEX_JAVASCRIPT.ADD_VALUE( P_DYNAMIC_ACTION.ATTRIBUTE_01, TRUE ) ||',
'    APEX_JAVASCRIPT.ADD_VALUE( APEX_PLUGIN_UTIL.PAGE_ITEM_NAMES_TO_JQUERY(P_DYNAMIC_ACTION.ATTRIBUTE_03), TRUE ) ||',
'    APEX_JAVASCRIPT.ADD_VALUE( VR_REQUIRE_ESCAPE, FALSE ) ||',
'    '');}'';',
'',
'    RETURN VR_RESULT;',
'END;'))
,p_api_version=>1
,p_render_function=>'F_RENDER'
,p_ajax_function=>'F_AJAX'
,p_substitute_attributes=>true
,p_subscribe_plugin_settings=>true
,p_help_text=>wwv_flow_string.join(wwv_flow_t_varchar2(
'This dynamic action plugin allows to render a notification menu which gets its information through an SQL statement. It also has many configuration options and an automatic refresh (if desired). Unfortunately, it is only available with the Universal '
||'Theme 1.1 in Apex 5.1.1 or above. If you want to use it in older Themes then you have to customize the CSS style.',
'',
'To Trigger a manual refresh just create a dynmic action e.g. on button click with the action "Refresh" and set as "Affected Element" a jQuery Selector. Then enter the ID that was set as Element ID for Notification Menu.'))
,p_version_identifier=>'1.1.1'
,p_about_url=>'https://github.com/RonnyWeiss/Apex-Notification-Menu-for-NavBar'
,p_files_version=>1176
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(138285470794301569216)
,p_plugin_id=>wwv_flow_api.id(138285470529447569213)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>1
,p_display_sequence=>4
,p_prompt=>'ConfigJSON'
,p_attribute_type=>'JAVASCRIPT'
,p_is_required=>true
,p_default_value=>wwv_flow_string.join(wwv_flow_t_varchar2(
'{',
'   "refresh": 0,',
'   "mainIcon": "fa-bell",',
'   "mainIconColor": "white",',
'   "mainIconBackgroundColor": "rgba(70,70,70,0.9)",',
'   "mainIconBlinking": false,',
'   "counterBackgroundColor": "rgb(232, 55, 55 )",',
'   "counterFontColor": "white",',
'   "linkTargetBlank": true,',
'   "showAlways": false',
'}'))
,p_supported_ui_types=>'DESKTOP:JQM_SMARTPHONE'
,p_is_translatable=>false
,p_help_text=>wwv_flow_string.join(wwv_flow_t_varchar2(
'<pre>',
'{',
'   "refresh": 0,',
'   "mainIcon": "fa-bell",',
'   "mainIconColor": "white",',
'   "mainIconBackgroundColor": "rgba(70,70,70,0.9)",',
'   "mainIconBlinking": false,',
'   "counterBackgroundColor": "rgb(232, 55, 55 )",',
'   "counterFontColor": "white",',
'   "linkTargetBlank": true,',
'   "showAlways": false',
'}',
'</pre>',
'<br>',
'<h3>Explanation:</h3>',
'  <dl>',
'  <dt>refresh (number)</dt>',
'  <dd>refresh time of cards in seconds if 0 then no refresh will be set</dd>',
'  <dl>',
'  <dt>mainIcon(string)</dt>',
'  <dd>icon of the menu</dd>',
'  <dl>',
'  <dt>mainIconColor(string)</dt>',
'  <dd>color of the icon e.g. #ffffff, green...</dd>',
'  <dl>',
'  <dt>counterBackgroundColor(string)</dt>',
'  <dd>color of the icon background e.g. #ffffff, green...</dd>',
'  <dl>',
'  <dt>mainIconBlinking(boolean)</dt>',
'  <dd>used to get icon blinking</dd>',
'  <dl>',
'  <dt>counterBackgroundColor(string)</dt>',
'  <dd>color of the counter background e.g. #ffffff, green...</dd>',
'  <dl>',
'  <dt>counterFontColor(string)</dt>',
'  <dd>color of the counter font color e.g. #ffffff, green...</dd>',
'  <dl>',
'  <dt>linkTargetBlank(boolean)</dt>',
'  <dd>link to target blank or not</dd>',
'  <dl>',
'  <dt>showAlways(boolean)</dt>',
'  <dd>Use to set if also shown when no notifications occured</dd>'))
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(138287077394138746845)
,p_plugin_id=>wwv_flow_api.id(138285470529447569213)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>2
,p_display_sequence=>3
,p_prompt=>'Element ID'
,p_attribute_type=>'TEXT'
,p_is_required=>true
,p_default_value=>'notification-menu'
,p_is_translatable=>false
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(138316351893608835518)
,p_plugin_id=>wwv_flow_api.id(138285470529447569213)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>3
,p_display_sequence=>2
,p_prompt=>'Items to Submit'
,p_attribute_type=>'PAGE ITEMS'
,p_is_required=>false
,p_is_translatable=>false
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(138316363470361838483)
,p_plugin_id=>wwv_flow_api.id(138285470529447569213)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>4
,p_display_sequence=>1
,p_prompt=>'SQL Source'
,p_attribute_type=>'SQL'
,p_is_required=>true
,p_default_value=>wwv_flow_string.join(wwv_flow_t_varchar2(
'SELECT /* sets the icon of the list item */',
'    ''fa-exclamation-triangle'' AS NOTE_ICON, ',
'    /* sets the color of the list icon */',
'    ''rgb(192,0,15)'' AS NOTE_ICON_COLOR, ',
'    /* sets the title of the list item (html possible) */',
'    ''Alarm occurred'' AS NOTE_HEADER, ',
'    /* sets the text of the list item (html possible */',
'    ''There''''s an alarm in <b>Station 3</b>. Error code is <b style="color:rgba(192,0,15);">#304-AD. </b>'' AS NOTE_TEXT, ',
'    /* set the link when click on list item */',
'    ''https://github.com/RonnyWeiss'' AS NOTE_LINK, ',
'    /* sets the color of the left box shadow */',
'    ''rgb(192,0,15)'' AS NOTE_COLOR',
'FROM',
'    DUAL',
'WHERE',
'    1 = ROUND(',
'        DBMS_RANDOM.VALUE(',
'            0,',
'            1',
'        )',
'    )',
'UNION ALL',
'SELECT',
'    ''fa-wrench'' AS NOTE_ICON,',
'    ''#3e6ebc'' AS NOTE_ICON_COLOR,',
'    ''System maintenance'' AS NOTE_HEADER,',
'    ''In the time between <b>08:30</b> and <b>11:00</b> a system maintenance takes place. The systems can only be used in read-only mode and are limited in use'' AS NOTE_TEXT,',
'    ''https://apex.world'' AS NOTE_LINK,',
'    ''#3e6ebc'' AS NOTE_COLOR',
'FROM',
'    DUAL',
'WHERE',
'    2 = ROUND(',
'        DBMS_RANDOM.VALUE(',
'            1,',
'            2',
'        )',
'    )',
'UNION ALL',
'SELECT',
'    ''fa-cloud-upload'' AS NOTE_ICON,',
'    ''#26a043'' AS NOTE_ICON_COLOR,',
'    ''Upload completed'' AS NOTE_HEADER,',
'    ''Your files have been successfully uploaded and processed'' AS NOTE_TEXT,',
'    NULL AS NOTE_LINK,',
'    ''#26a043'' AS NOTE_COLOR',
'FROM',
'    DUAL',
'WHERE',
'    3 = ROUND(',
'        DBMS_RANDOM.VALUE(',
'            3,',
'            4',
'        )',
'    )',
'UNION ALL',
'SELECT',
'    ''fa-calendar-times-o'' AS NOTE_ICON,',
'    ''#ba6f14'' AS NOTE_ICON_COLOR,',
'    ''Commissioning overdue'' AS NOTE_HEADER,',
'    ''Commissioning of system <b>FEW03</b> is overdue for <b>3 days</b>. Please talk to the responsible persons about a solution.'' AS NOTE_TEXT,',
'    NULL AS NOTE_LINK,',
'    ''#ba6f14'' AS NOTE_COLOR',
'FROM',
'    DUAL',
'WHERE',
'    4 = ROUND(',
'        DBMS_RANDOM.VALUE(',
'            4,',
'            5',
'        )',
'    )'))
,p_sql_min_column_count=>1
,p_is_translatable=>false
,p_help_text=>wwv_flow_string.join(wwv_flow_t_varchar2(
'<pre>',
'SELECT /* sets the icon of the list item */',
'    ''fa-exclamation-triangle'' AS NOTE_ICON, ',
'    /* sets the color of the list icon */',
'    ''rgb(192,0,15)'' AS NOTE_ICON_COLOR, ',
'    /* sets the title of the list item (html possible) */',
'    ''Alarm occurred'' AS NOTE_HEADER, ',
'    /* sets the text of the list item (html possible */',
'    ''There''''s an alarm in &lt;b&gt;Station 3&lt;/b&gt;. Error code is &lt;b style=&quot;color:rgba(192,0,15);&quot;&gt;#304-AD. &lt;/b&gt;'' AS NOTE_TEXT, ',
'    /* set the link when click on list item */',
'    ''https://github.com/RonnyWeiss'' AS NOTE_LINK, ',
'    /* sets the color of the left box shadow */',
'    ''rgb(192,0,15)'' AS NOTE_COLOR',
'FROM',
'    DUAL',
'</pre>'))
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(73265847769135965781)
,p_plugin_id=>wwv_flow_api.id(138285470529447569213)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>5
,p_display_sequence=>50
,p_prompt=>'Escape special Characters'
,p_attribute_type=>'CHECKBOX'
,p_is_required=>false
,p_default_value=>'Y'
,p_is_translatable=>false
,p_help_text=>'This value determines whether all texts that the plug-in inserts into the page should be escaped. This is necessary if texts come from user input or insecure sources to prevent XSS.'
);
wwv_flow_api.create_plugin_event(
 p_id=>wwv_flow_api.id(17252763699692308273)
,p_plugin_id=>wwv_flow_api.id(138285470529447569213)
,p_name=>'refresh-apex-notification-menu'
,p_display_name=>'Refresh Notification Menu'
);
end;
/
begin
wwv_flow_api.g_varchar2_table := wwv_flow_api.empty_varchar2_table;
wwv_flow_api.g_varchar2_table(1) := '4D4954204C6963656E73650A0A436F7079726967687420286329203230313920526F6E6E792057656973730A0A5065726D697373696F6E20697320686572656279206772616E7465642C2066726565206F66206368617267652C20746F20616E79207065';
wwv_flow_api.g_varchar2_table(2) := '72736F6E206F627461696E696E67206120636F70790A6F66207468697320736F66747761726520616E64206173736F63696174656420646F63756D656E746174696F6E2066696C657320287468652022536F66747761726522292C20746F206465616C0A';
wwv_flow_api.g_varchar2_table(3) := '696E2074686520536F66747761726520776974686F7574207265737472696374696F6E2C20696E636C7564696E6720776974686F7574206C696D69746174696F6E20746865207269676874730A746F207573652C20636F70792C206D6F646966792C206D';
wwv_flow_api.g_varchar2_table(4) := '657267652C207075626C6973682C20646973747269627574652C207375626C6963656E73652C20616E642F6F722073656C6C0A636F70696573206F662074686520536F6674776172652C20616E6420746F207065726D697420706572736F6E7320746F20';
wwv_flow_api.g_varchar2_table(5) := '77686F6D2074686520536F6674776172652069730A6675726E697368656420746F20646F20736F2C207375626A65637420746F2074686520666F6C6C6F77696E6720636F6E646974696F6E733A0A0A5468652061626F766520636F70797269676874206E';
wwv_flow_api.g_varchar2_table(6) := '6F7469636520616E642074686973207065726D697373696F6E206E6F74696365207368616C6C20626520696E636C7564656420696E20616C6C0A636F70696573206F72207375627374616E7469616C20706F7274696F6E73206F662074686520536F6674';
wwv_flow_api.g_varchar2_table(7) := '776172652E0A0A54484520534F4654574152452049532050524F564944454420224153204953222C20574954484F55542057415252414E5459204F4620414E59204B494E442C2045585052455353204F520A494D504C4945442C20494E434C5544494E47';
wwv_flow_api.g_varchar2_table(8) := '20425554204E4F54204C494D4954454420544F205448452057415252414E54494553204F46204D45524348414E544142494C4954592C0A4649544E45535320464F52204120504152544943554C415220505552504F534520414E44204E4F4E494E465249';
wwv_flow_api.g_varchar2_table(9) := '4E47454D454E542E20494E204E4F204556454E54205348414C4C205448450A415554484F5253204F5220434F5059524947485420484F4C44455253204245204C4941424C4520464F5220414E5920434C41494D2C2044414D41474553204F52204F544845';
wwv_flow_api.g_varchar2_table(10) := '520A4C494142494C4954592C205748455448455220494E20414E20414354494F4E204F4620434F4E54524143542C20544F5254204F52204F54484552574953452C2041524953494E472046524F4D2C0A4F5554204F46204F5220494E20434F4E4E454354';
wwv_flow_api.g_varchar2_table(11) := '494F4E20574954482054484520534F465457415245204F522054484520555345204F52204F54484552204445414C494E475320494E205448450A534F4654574152452E0A';
null;
end;
/
begin
wwv_flow_api.create_plugin_file(
 p_id=>wwv_flow_api.id(138285471872020569224)
,p_plugin_id=>wwv_flow_api.id(138285470529447569213)
,p_file_name=>'LICENSE'
,p_mime_type=>'application/octet-stream'
,p_file_charset=>'utf-8'
,p_file_content=>wwv_flow_api.varchar2_to_blob(wwv_flow_api.g_varchar2_table)
);
end;
/
begin
wwv_flow_api.g_varchar2_table := wwv_flow_api.empty_varchar2_table;
wwv_flow_api.g_varchar2_table(1) := '766172206E6F74696669636174696F6E4D656E753D66756E6374696F6E28297B2275736520737472696374223B766172206F3D7B76657273696F6E3A22312E302E31222C65736361706548544D4C3A66756E6374696F6E286F297B6966286E756C6C3D3D';
wwv_flow_api.g_varchar2_table(2) := '3D6F2972657475726E206E756C6C3B696628766F69642030213D3D6F297B696628226F626A656374223D3D747970656F66206F297472797B6F3D4A534F4E2E737472696E67696679286F297D6361746368286F297B7D7472797B72657475726E20617065';
wwv_flow_api.g_varchar2_table(3) := '782E7574696C2E65736361706548544D4C28537472696E67286F29297D63617463682872297B72657475726E286F3D537472696E67286F29292E7265706C616365282F262F672C2226616D703B22292E7265706C616365282F3C2F672C22266C743B2229';
wwv_flow_api.g_varchar2_table(4) := '2E7265706C616365282F3E2F672C222667743B22292E7265706C616365282F222F672C222671756F743B22292E7265706C616365282F272F672C2226237832373B22292E7265706C616365282F5C2F2F672C2226237832463B22297D7D7D2C6A736F6E53';
wwv_flow_api.g_varchar2_table(5) := '617665457874656E643A66756E6374696F6E286F2C72297B76617220613D7B7D3B69662822737472696E67223D3D747970656F662072297472797B723D4A534F4E2E70617273652872297D6361746368286F297B636F6E736F6C652E6572726F72282245';
wwv_flow_api.g_varchar2_table(6) := '72726F72207768696C652074727920746F207061727365207564436F6E6669674A534F4E2E20506C6561736520636865636B20796F757220436F6E666967204A534F4E2E205374616E6461726420436F6E6669672077696C6C20626520757365642E2229';
wwv_flow_api.g_varchar2_table(7) := '2C636F6E736F6C652E6572726F72286F292C636F6E736F6C652E6572726F722872297D656C736520613D723B7472797B613D242E657874656E642821302C6F2C72297D63617463682872297B636F6E736F6C652E6572726F7228224572726F7220776869';
wwv_flow_api.g_varchar2_table(8) := '6C652074727920746F206D65726765207564436F6E6669674A534F4E20696E746F205374616E64617264204A534F4E20696620616E7920617474726962757465206973206D697373696E672E20506C6561736520636865636B20796F757220436F6E6669';
wwv_flow_api.g_varchar2_table(9) := '67204A534F4E2E205374616E6461726420436F6E6669672077696C6C20626520757365642E22292C636F6E736F6C652E6572726F722872292C613D6F2C636F6E736F6C652E6572726F722861297D72657475726E20617D7D3B72657475726E7B696E6974';
wwv_flow_api.g_varchar2_table(10) := '69616C697A653A66756E6374696F6E28722C612C652C6E2C74297B66756E6374696F6E206C286F297B6966286129617065782E7365727665722E706C7567696E28612C7B706167654974656D733A6E7D2C7B737563636573733A6F2C6572726F723A6675';
wwv_flow_api.g_varchar2_table(11) := '6E6374696F6E2872297B636F6E736F6C652E6C6F6728722E726573706F6E736554657874292C6F287B726F773A5B7B4E4F54455F49434F4E3A2266612D6578636C616D6174696F6E2D747269616E676C65222C4E4F54455F49434F4E5F434F4C4F523A22';
wwv_flow_api.g_varchar2_table(12) := '23464630303030222C4E4F54455F4845414445523A224572726F72206F63637572656421222C4E4F54455F544558543A224572726F72206F636375726564207768696C652074727920746F20676574206E657720646174612E222C4E4F54455F434F4C4F';
wwv_flow_api.g_varchar2_table(13) := '523A2223464630303030227D5D7D297D2C64617461547970653A226A736F6E227D293B656C7365207472797B6928646174614A534F4E297D6361746368286F297B636F6E736F6C652E6C6F6728226E6565642064617461206A736F6E22292C636F6E736F';
wwv_flow_api.g_varchar2_table(14) := '6C652E6C6F67286F297D7D66756E6374696F6E20692861297B2131213D3D74262628632E636F756E7465724261636B67726F756E64436F6C6F723D6F2E65736361706548544D4C28632E636F756E7465724261636B67726F756E64436F6C6F72292C632E';
wwv_flow_api.g_varchar2_table(15) := '636F756E746572466F6E74436F6C6F723D6F2E65736361706548544D4C28632E636F756E746572466F6E74436F6C6F72292C632E6D61696E49636F6E3D6F2E65736361706548544D4C28632E6D61696E49636F6E292C632E6D61696E49636F6E4261636B';
wwv_flow_api.g_varchar2_table(16) := '67726F756E64436F6C6F723D6F2E65736361706548544D4C28632E6D61696E49636F6E4261636B67726F756E64436F6C6F72292C632E6D61696E49636F6E436F6C6F723D6F2E65736361706548544D4C28632E6D61696E49636F6E436F6C6F7229293B76';
wwv_flow_api.g_varchar2_table(17) := '617220653D2428223C6469763E3C2F6469763E22293B652E616464436C6173732822746F67676C654E6F74696669636174696F6E7322292C652E6174747228226964222C722B225F746F67676C654E6F746522292C652E617474722822746F67676C6564';
wwv_flow_api.g_varchar2_table(18) := '222C227472756522293B766172206E3D2223222B722B225F756C223B652E6F6E2822746F756368737461727420636C69636B222C66756E6374696F6E28297B766172206F3D2266616C7365223D3D652E617474722822746F67676C656422293F22747275';
wwv_flow_api.g_varchar2_table(19) := '65223A2266616C7365223B652E617474722822746F67676C6564222C6F292C24286E292E66616465546F67676C6528226661737422297D292C2428646F63756D656E74292E6F6E2822746F756368737461727420636C69636B222C66756E6374696F6E28';
wwv_flow_api.g_varchar2_table(20) := '6F297B21652E6973286F2E746172676574292626303D3D3D652E686173286F2E746172676574292E6C656E67746826262124286F2E746172676574292E706172656E7473286E292E6C656E6774683E3026262266616C7365223D3D652E61747472282274';
wwv_flow_api.g_varchar2_table(21) := '6F67676C65642229262628652E617474722822746F67676C6564222C2130292C24286E292E66616465546F67676C652822666173742229297D293B766172206C3D2428223C6469763E3C2F6469763E22293B6C2E616464436C6173732822636F756E7422';
wwv_flow_api.g_varchar2_table(22) := '292C652E617070656E64286C293B76617220693D2428223C6469763E3C2F6469763E22293B692E616464436C61737328226E756D22292C692E63737328226261636B67726F756E64222C632E636F756E7465724261636B67726F756E64436F6C6F72292C';
wwv_flow_api.g_varchar2_table(23) := '692E6373732822636F6C6F72222C632E636F756E746572466F6E74436F6C6F72292C692E6174747228226964222C722B225F6E756D64697622292C692E68746D6C28612E726F772E6C656E677468292C6C2E617070656E642869293B76617220673D2428';
wwv_flow_api.g_varchar2_table(24) := '223C6C6162656C3E3C2F6C6162656C3E22293B672E616464436C617373282273686F7722292C672E63737328226261636B67726F756E64222C632E6D61696E49636F6E4261636B67726F756E64436F6C6F72293B76617220753D2428223C693E3C2F693E';
wwv_flow_api.g_varchar2_table(25) := '22293B752E616464436C6173732822666122292C752E616464436C61737328632E6D61696E49636F6E292C752E6373732822636F6C6F72222C632E6D61696E49636F6E436F6C6F72292C632E6D61696E49636F6E426C696E6B696E672626752E61646443';
wwv_flow_api.g_varchar2_table(26) := '6C617373282266612D626C696E6B22292C672E617070656E642875292C652E617070656E642867292C642E617070656E642865292C732861297D66756E6374696F6E20732861297B76617220653D2223222B722B225F746F67676C654E6F7465223B6966';
wwv_flow_api.g_varchar2_table(27) := '28242865292E6869646528292C612E726F77297B766172206E3D2223222B722B225F6E756D646976222C6C3D2223222B722B225F756C223B612E726F772E6C656E6774683E303F2824286E292E63737328226261636B67726F756E64222C632E636F756E';
wwv_flow_api.g_varchar2_table(28) := '7465724261636B67726F756E64436F6C6F72292C242865292E73686F7728292C24286E292E73686F7728292C24286E292E7465787428612E726F772E6C656E677468292C24286C292E72656D6F766528292C66756E6374696F6E28612C65297B76617220';
wwv_flow_api.g_varchar2_table(29) := '6E3D2428223C756C3E3C2F756C3E22293B6E2E6174747228226964222C722B225F756C22292C6E2E616464436C61737328226E6F74696669636174696F6E7322292C6E2E616464436C61737328226E6F74696669636174696F6E73746F67676C6522293B';
wwv_flow_api.g_varchar2_table(30) := '766172206C3D2223222B722B225F746F67676C654E6F7465223B2266616C7365223D3D24286C292E617474722822746F67676C6564222926266E2E746F67676C6528293B696628652E726F7729666F722876617220693D303B693C652E726F772E6C656E';
wwv_flow_api.g_varchar2_table(31) := '6774683B692B2B297B2131213D3D74262628652E726F775B695D2E4E4F54455F484541444552262628652E726F775B695D2E4E4F54455F4845414445523D6F2E65736361706548544D4C28652E726F775B695D2E4E4F54455F48454144455229292C652E';
wwv_flow_api.g_varchar2_table(32) := '726F775B695D2E4E4F54455F49434F4E262628652E726F775B695D2E4E4F54455F49434F4E3D6F2E65736361706548544D4C28652E726F775B695D2E4E4F54455F49434F4E29292C652E726F775B695D2E4E4F54455F49434F4E5F434F4C4F5226262865';
wwv_flow_api.g_varchar2_table(33) := '2E726F775B695D2E4E4F54455F49434F4E5F434F4C4F523D6F2E65736361706548544D4C28652E726F775B695D2E4E4F54455F49434F4E5F434F4C4F5229292C652E726F775B695D2E4E4F54455F54455854262628652E726F775B695D2E4E4F54455F54';
wwv_flow_api.g_varchar2_table(34) := '4558543D6F2E65736361706548544D4C28652E726F775B695D2E4E4F54455F544558542929293B76617220733D2428223C613E3C2F613E22293B652E726F775B695D2E4E4F54455F4C494E4B262628732E61747472282268726566222C652E726F775B69';
wwv_flow_api.g_varchar2_table(35) := '5D2E4E4F54455F4C494E4B292C632E6C696E6B546172676574426C616E6B2626732E617474722822746172676574222C225F626C616E6B22292C732E6F6E2822746F756368737461727420636C69636B222C66756E6374696F6E286F297B2266616C7365';
wwv_flow_api.g_varchar2_table(36) := '223D3D612E617474722822746F67676C65642229262628612E617474722822746F67676C6564222C2130292C24286E292E66616465546F67676C652822666173742229297D29293B76617220643D2428223C6C693E3C2F6C693E22293B642E616464436C';
wwv_flow_api.g_varchar2_table(37) := '61737328226E6F746522292C652E726F775B695D2E4E4F54455F434F4C4F522626642E6373732822626F782D736861646F77222C222D35707820302030203020222B652E726F775B695D2E4E4F54455F434F4C4F52293B76617220673D2428223C646976';
wwv_flow_api.g_varchar2_table(38) := '3E3C2F6469763E22293B672E616464436C61737328226E6F74652D68656164657222293B76617220753D2428223C693E3C2F693E22293B752E616464436C6173732822666122292C652E726F775B695D2E4E4F54455F49434F4E2626752E616464436C61';
wwv_flow_api.g_varchar2_table(39) := '737328652E726F775B695D2E4E4F54455F49434F4E292C652E726F775B695D2E4E4F54455F49434F4E5F434F4C4F522626752E6373732822636F6C6F72222C652E726F775B695D2E4E4F54455F49434F4E5F434F4C4F52292C752E616464436C61737328';
wwv_flow_api.g_varchar2_table(40) := '2266612D6C6722292C672E617070656E642875292C652E726F775B695D2E4E4F54455F4845414445522626672E617070656E6428652E726F775B695D2E4E4F54455F484541444552292C642E617070656E642867293B766172204F3D2428223C7370616E';
wwv_flow_api.g_varchar2_table(41) := '3E3C2F7370616E3E22293B4F2E616464436C61737328226E6F74652D696E666F22292C652E726F775B695D2E4E4F54455F5445585426264F2E68746D6C28652E726F775B695D2E4E4F54455F54455854292C642E617070656E64284F292C732E61707065';
wwv_flow_api.g_varchar2_table(42) := '6E642864292C6E2E617070656E642873297D242822626F647922292E617070656E64286E297D28242865292C6129293A28632E73686F77416C77617973262628242865292E73686F7728292C24286E292E686964652829292C24286C292E72656D6F7665';
wwv_flow_api.g_varchar2_table(43) := '2829297D7D76617220633D7B7D3B633D6F2E6A736F6E53617665457874656E64287B726566726573683A302C6D61696E49636F6E3A2266612D62656C6C222C6D61696E49636F6E436F6C6F723A227768697465222C6D61696E49636F6E4261636B67726F';
wwv_flow_api.g_varchar2_table(44) := '756E64436F6C6F723A22726762612837302C37302C37302C302E3929222C6D61696E49636F6E426C696E6B696E673A21312C636F756E7465724261636B67726F756E64436F6C6F723A22726762283233322C2035352C2035352029222C636F756E746572';
wwv_flow_api.g_varchar2_table(45) := '466F6E74436F6C6F723A227768697465222C6C696E6B546172676574426C616E6B3A21302C73686F77416C776179733A21317D2C65293B76617220643D66756E6374696F6E286F297B76617220723D2428223C6C693E3C2F6C693E22293B722E61646443';
wwv_flow_api.g_varchar2_table(46) := '6C6173732822742D4E617669676174696F6E4261722D6974656D22293B76617220653D2428223C6469763E3C2F6469763E22293B72657475726E20652E6174747228226964222C6F292C652E62696E6428226170657872656672657368222C66756E6374';
wwv_flow_api.g_varchar2_table(47) := '696F6E28297B303D3D642E6368696C6472656E28227370616E22292E6C656E677468262628613F6C2873293A7328646174614A534F4E29297D292C722E617070656E642865292C2428222E742D4E617669676174696F6E42617222292E70726570656E64';
wwv_flow_api.g_varchar2_table(48) := '2872292C657D2872293B6C2869292C632E726566726573683E302626736574496E74657276616C2866756E6374696F6E28297B303D3D642E6368696C6472656E28227370616E22292E6C656E677468262628613F6C2873293A7328646174614A534F4E29';
wwv_flow_api.g_varchar2_table(49) := '297D2C3165332A632E72656672657368297D7D7D28293B';
null;
end;
/
begin
wwv_flow_api.create_plugin_file(
 p_id=>wwv_flow_api.id(138320590213852156199)
,p_plugin_id=>wwv_flow_api.id(138285470529447569213)
,p_file_name=>'script.min.js'
,p_mime_type=>'text/javascript'
,p_file_charset=>'utf-8'
,p_file_content=>wwv_flow_api.varchar2_to_blob(wwv_flow_api.g_varchar2_table)
);
end;
/
begin
wwv_flow_api.g_varchar2_table := wwv_flow_api.empty_varchar2_table;
wwv_flow_api.g_varchar2_table(1) := '2E746F67676C654E6F74696669636174696F6E737B6D617267696E2D72696768743A3870783B706F736974696F6E3A72656C61746976653B646973706C61793A2D7765626B69742D696E6C696E652D626F783B646973706C61793A2D6D732D696E6C696E';
wwv_flow_api.g_varchar2_table(2) := '652D666C6578626F783B646973706C61793A696E6C696E652D666C65783B666C6F61743A72696768743B6865696768743A323870783B77696474683A323870783B2D7765626B69742D757365722D73656C6563743A6E6F6E653B2D6D6F7A2D757365722D';
wwv_flow_api.g_varchar2_table(3) := '73656C6563743A6E6F6E653B2D6D732D757365722D73656C6563743A6E6F6E653B757365722D73656C6563743A6E6F6E653B637572736F723A706F696E7465727D2E746F67676C654E6F74696669636174696F6E73202E73686F777B2D7765626B69742D';
wwv_flow_api.g_varchar2_table(4) := '626F782D666C65783A313B2D6D732D666C65783A313B666C65783A313B6D617267696E3A6175746F3B6865696768743A323870783B6D61782D77696474683A323870783B746578742D616C69676E3A63656E7465723B626F726465722D7261646975733A';
wwv_flow_api.g_varchar2_table(5) := '3530253B6261636B67726F756E643A7267626128302C302C302C2E35293B666F6E742D73697A653A323870783B2D7765626B69742D7472616E736974696F6E3A616C6C2031733B7472616E736974696F6E3A616C6C2031733B637572736F723A706F696E';
wwv_flow_api.g_varchar2_table(6) := '7465727D2E746F67676C654E6F74696669636174696F6E73202E73686F773A686F7665727B6261636B67726F756E643A233030307D2E746F67676C654E6F74696669636174696F6E73202E73686F7720697B6C696E652D6865696768743A323870783B63';
wwv_flow_api.g_varchar2_table(7) := '6F6C6F723A236666667D2E636F756E747B706F736974696F6E3A6162736F6C7574653B746F703A2D3270783B72696768743A3770783B637572736F723A706F696E7465727D2E636F756E74202E6E756D7B706F736974696F6E3A6162736F6C7574653B74';
wwv_flow_api.g_varchar2_table(8) := '6F703A303B6C6566743A303B6261636B67726F756E643A236632323B626F726465722D7261646975733A3530253B77696474683A313870783B6865696768743A313870783B746578742D616C69676E3A63656E7465723B6C696E652D6865696768743A31';
wwv_flow_api.g_varchar2_table(9) := '3770783B666F6E742D73697A653A313170783B2D7765626B69742D626F782D736861646F773A302031707820337078207267626128302C302C302C2E3235293B626F782D736861646F773A302031707820337078207267626128302C302C302C2E323529';
wwv_flow_api.g_varchar2_table(10) := '3B626F726465723A31707820736F6C696420726762612837302C37302C37302C2E32293B2D7765626B69742D7472616E736974696F6E3A616C6C202E33733B7472616E736974696F6E3A616C6C202E33733B636F6C6F723A236666667D2E6E6F74696669';
wwv_flow_api.g_varchar2_table(11) := '636174696F6E737B706F736974696F6E3A66697865643B746F703A343270783B72696768743A313070783B77696474683A34303070783B6261636B67726F756E643A72676261283235302C3235302C3235302C31293B626F726465722D7261646975733A';
wwv_flow_api.g_varchar2_table(12) := '3270783B2D7765626B69742D626F782D736861646F773A302033707820367078207267626128302C302C302C2E35293B626F782D736861646F773A302033707820367078207267626128302C302C302C2E35293B7A2D696E6465783A393939393B6D6178';
wwv_flow_api.g_varchar2_table(13) := '2D6865696768743A373576683B6F766572666C6F773A6175746F7D406D65646961206F6E6C792073637265656E20616E6420286D61782D77696474683A3638307078297B2E6E6F74696669636174696F6E737B77696474683A383576773B6D61782D7769';
wwv_flow_api.g_varchar2_table(14) := '6474683A34303070787D7D2E6E6F74696669636174696F6E73746F67676C657B646973706C61793A6E6F6E657D2E6E6F74696669636174696F6E73202E6E6F74657B6D617267696E3A30203570783B626F726465722D626F74746F6D3A31707820736F6C';
wwv_flow_api.g_varchar2_table(15) := '696420236536653665363B6C696E652D6865696768743A313070783B2D7765626B69742D7472616E736974696F6E3A616C6C202E32733B7472616E736974696F6E3A616C6C202E32733B6F766572666C6F773A68696464656E3B636F6C6F723A23343634';
wwv_flow_api.g_varchar2_table(16) := '3634363B70616464696E672D6C6566743A3570787D2E6E6F74696669636174696F6E73202E6E6F7465202E6E6F74652D696E666F7B646973706C61793A626C6F636B3B70616464696E673A302033307078203230707820343070783B6F766572666C6F77';
wwv_flow_api.g_varchar2_table(17) := '2D777261703A627265616B2D776F72643B776F72642D777261703A627265616B2D776F72643B2D6D732D68797068656E733A6175746F3B2D6D6F7A2D68797068656E733A6175746F3B2D7765626B69742D68797068656E733A6175746F3B68797068656E';
wwv_flow_api.g_varchar2_table(18) := '733A6175746F3B77696474683A313030253B6C696E652D6865696768743A323070787D406B65796672616D65732066612D626C696E6B7B30252C313030257B6F7061636974793A317D3530257B6F7061636974793A307D7D2E66612D626C696E6B7B2D77';
wwv_flow_api.g_varchar2_table(19) := '65626B69742D616E696D6174696F6E3A66612D626C696E6B203273206C696E65617220696E66696E6974653B2D6D6F7A2D616E696D6174696F6E3A66612D626C696E6B203273206C696E65617220696E66696E6974653B2D6D732D616E696D6174696F6E';
wwv_flow_api.g_varchar2_table(20) := '3A66612D626C696E6B203273206C696E65617220696E66696E6974653B2D6F2D616E696D6174696F6E3A66612D626C696E6B203273206C696E65617220696E66696E6974653B616E696D6174696F6E3A66612D626C696E6B203273206C696E6561722069';
wwv_flow_api.g_varchar2_table(21) := '6E66696E6974657D2E6E6F74696669636174696F6E7320617B746578742D6465636F726174696F6E3A6E6F6E657D2E6E6F74696669636174696F6E73202E6E6F7465202E6E6F74652D6865616465727B666F6E742D7765696768743A3730303B74657874';
wwv_flow_api.g_varchar2_table(22) := '2D6F766572666C6F773A656C6C69707369733B6F766572666C6F773A68696464656E3B77686974652D73706163653A6E6F777261703B77696474683A313030253B70616464696E672D72696768743A313070783B6C696E652D6865696768743A34307078';
wwv_flow_api.g_varchar2_table(23) := '7D2E6E6F74696669636174696F6E73202E6E6F74653A66697273742D6F662D747970657B6D617267696E2D746F703A307D2E6E6F74696669636174696F6E73202E6E6F74653A686F7665727B626F782D736861646F773A2D357078203020302030202334';
wwv_flow_api.g_varchar2_table(24) := '363436343621696D706F7274616E747D2E6E6F74696669636174696F6E73202E6E6F7465202E6E6F74652D68656164657220697B706F736974696F6E3A72656C61746976653B746F703A2D3170783B6D617267696E2D72696768743A313070783B766572';
wwv_flow_api.g_varchar2_table(25) := '746963616C2D616C69676E3A6D6964646C653B77696474683A333070783B746578742D616C69676E3A63656E7465727D';
null;
end;
/
begin
wwv_flow_api.create_plugin_file(
 p_id=>wwv_flow_api.id(138320590832348156749)
,p_plugin_id=>wwv_flow_api.id(138285470529447569213)
,p_file_name=>'style.min.css'
,p_mime_type=>'text/css'
,p_file_charset=>'utf-8'
,p_file_content=>wwv_flow_api.varchar2_to_blob(wwv_flow_api.g_varchar2_table)
);
end;
/
begin
wwv_flow_api.import_end(p_auto_install_sup_obj => nvl(wwv_flow_application_install.get_auto_install_sup_obj, false), p_is_component_import => true);
commit;
end;
/
set verify on feedback on define on
prompt  ...done
